# Alvin Integration Package

This package contains all modules related with integrating a Producer such as Airflow with Alvin platform.

## Running locally

### Build Docker Images

Execute the following command for Airflow 2:

```make build-airflow```

Execute the following command for Airflow 1:

```make build-legacy```

### Running Airflow

Execute the following command for Airflow 2:

```make run-airflow```

Execute the following command for Airflow 1:

```make run-legacy```
